==> mx-cleanup_25.5.01.tar.xz: BUILD/translations/mx-cleanup_es_ES.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="es_ES">
<context>
    <name>MainWindow</name>
    <message>
        <location filename="../mainwindow.ui" line="14"/>
        <location filename="../mainwindow.cpp" line="122"/>
        <location filename="../mainwindow.cpp" line="579"/>
        <source>MX Cleanup</source>
        <translation>MX Limpiador</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="663"/>
        <source>Display help </source>
        <translation>Mostrar la ayuda</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="666"/>
        <source>Help</source>
        <translation>Ayuda</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="672"/>
        <source>Alt+H</source>
        <translation>Alt+H</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="638"/>
        <source>About this application</source>
        <translation>Acerca de esta aplicación</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="24"/>
        <source>Main</source>
        <translation>Principal</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="519"/>
        <source>Tools</source>
        <translation>Herramientas</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="525"/>
        <source>Removal Tools</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="563"/>
        <source>Remove MX manuals for languages other than system default</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="641"/>
        <source>About...</source>
        <translation>Acerca de...</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="647"/>
        <source>Alt+B</source>
        <translation>Alt+B</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="761"/>
        <source>Quit application</source>
        <translation>Salir de la aplicación</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="764"/>
        <location filename="../mainwindow.cpp" line="680"/>
        <source>Close</source>
        <translation>Cerrar</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="770"/>
        <source>Alt+N</source>
        <translation>Alt+N</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="736"/>
        <source>Apply</source>
        <translation>Aplicar</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="422"/>
        <source>Empty Trash</source>
        <translation>Vaciar papelera</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="431"/>
        <source>Trash older than:</source>
        <translation>Papelera anterior a:</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="176"/>
        <location filename="../mainwindow.ui" line="236"/>
        <location filename="../mainwindow.ui" line="489"/>
        <location filename="../mainwindow.cpp" line="417"/>
        <source> days</source>
        <translation> días</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="444"/>
        <source>All users</source>
        <translation>Todos los usuarios</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="476"/>
        <source>Selected user</source>
        <translation>Usuario seleccionado</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="369"/>
        <source>Clear APT Cache</source>
        <translation>Limpiar Cache de APT</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="384"/>
        <source>Old files</source>
        <translation>Archivos antiguos</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="403"/>
        <source>All files</source>
        <translation>Todos los archivos</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="585"/>
        <source>Graphical Tool for Analyzing Disk Usage</source>
        <translation>Herramienta gráfica para Analizar el Uso del Disco</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="597"/>
        <source>Run Disk Usage Analyzer</source>
        <translation>Ejecutar Analizador de Uso del Disco</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="300"/>
        <source>Schedule</source>
        <translation>Programar</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="312"/>
        <source>No automatic clean</source>
        <translation>Sin limpieza automática</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="319"/>
        <source>At reboot</source>
        <translation>Al reiniciar</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="326"/>
        <source>Daily</source>
        <translation>Diariamente</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="333"/>
        <source>Weekly</source>
        <translation>Semanalmente</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="340"/>
        <source>Monthly</source>
        <translation>Mensualmente</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="58"/>
        <source>Free Disk Space for User</source>
        <translation>Espacio Libre en Disco para el Usuario</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="70"/>
        <location filename="../mainwindow.ui" line="86"/>
        <source>Select user to repair</source>
        <translation>Seleccione el usuario a reparar</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="73"/>
        <source>Select user:</source>
        <translation>Seleccionar usuario:</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="205"/>
        <source>Delete Logs</source>
        <translation>Borrar Registros</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="220"/>
        <source>All logs</source>
        <translation>Todos los registros</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="281"/>
        <source>Old logs</source>
        <translation>Registros antiguos</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="268"/>
        <source>Logs older than:</source>
        <translation>Registros anteriores a:</translation>
    </message>
    <message>
        <source>Removal tool</source>
        <translation type="vanished">Herramienta de eliminación</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="531"/>
        <source>Remove unused WiFi drivers</source>
        <translation>Eliminar controladores de WiFi no utilizados</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="550"/>
        <source>List and select kernels to remove</source>
        <translation>Lista y selección de los kerneles a eliminar</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="36"/>
        <source>Clean Flatpak</source>
        <translation>Limpiar Flatpak</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="42"/>
        <source>Remove unused runtimes</source>
        <translation>Eliminar los tiempos de ejecución no usados</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="102"/>
        <source>Clean Folders</source>
        <translation>Limpiar Carpetas</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="166"/>
        <source>Not accessed for:</source>
        <translation>No accesible por</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="114"/>
        <source>Cache</source>
        <translation>Cache</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="189"/>
        <source>All (potentially dangerous)</source>
        <translation>Todos (potencialmente peligroso)</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="143"/>
        <source>Thumbnails</source>
        <translation>Imágenes en miniatura</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="73"/>
        <source>Remove Manuals</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="73"/>
        <source>No manuals to remove.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="80"/>
        <source>Removing packages, please wait</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="254"/>
        <location filename="../mainwindow.cpp" line="720"/>
        <source>Press any key to close</source>
        <translation>Pulse cualquier tecla para cerrar</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="417"/>
        <source> day</source>
        <translation>día</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="432"/>
        <source>Error</source>
        <translation>Error</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="432"/>
        <source>Failed to elevate privileges</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="569"/>
        <source>Done</source>
        <translation>Hecho</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="571"/>
        <source>Cleanup script will run at reboot</source>
        <translation>El script de limpieza se ejecutará al reiniciar</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="572"/>
        <source>Cleanup command done</source>
        <translation>Orden de limpieza hecha</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="572"/>
        <source>%1 MiB were freed</source>
        <translation>%1 MiB fueron liberados</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="579"/>
        <source>About</source>
        <translation>Acerca de</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="580"/>
        <source>Version: </source>
        <translation>Versión: </translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="582"/>
        <source>Quick and safe removal of old files</source>
        <translation>Eliminación rápida y segura de archivos antiguos</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="584"/>
        <source>Copyright (c) MX Linux</source>
        <translation>Copyright (c) MX Linux</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="585"/>
        <source>%1 License</source>
        <translation>%1 Licencia</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="592"/>
        <source>%1 Help</source>
        <translation>%1 Ayuda</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="675"/>
        <source>Kernel currently in use: &lt;b&gt;%1&lt;/b&gt;</source>
        <translation>Kernel actualmente en uso: &lt;b&gt;%1&lt;/b&gt;</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="678"/>
        <source>Remove selected</source>
        <translation>Eliminar lo seleccionado</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="683"/>
        <source>Similar kernels that can be removed:</source>
        <translation>Kerneles similares que pueden eliminarse:</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="684"/>
        <source>Other kernels that can be removed:</source>
        <translation>Otros kerneles que pueden eliminarse:</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="687"/>
        <source>&lt;b&gt;Nothing to remove.&lt;/b&gt; Cannot remove kernel in use.</source>
        <translation>&lt;b&gt;Nada que eliminar.&lt;/b&gt; No puede eliminarse el kernel en uso.</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../about.cpp" line="70"/>
        <source>License</source>
        <translation>Licencia</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="71"/>
        <location filename="../about.cpp" line="81"/>
        <source>Changelog</source>
        <translation>Registro de cambios</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="72"/>
        <source>Cancel</source>
        <translation>Cancelar</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="94"/>
        <source>&amp;Close</source>
        <translation>&amp;Cerrar</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="53"/>
        <source>Quick safe removal of old files</source>
        <translation>Eliminación rápida y segura de archivos antiguos</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="79"/>
        <location filename="../main.cpp" line="87"/>
        <source>Error</source>
        <translation>Error</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="80"/>
        <source>You seem to be logged in as root, please log out and log in as normal user to use this program.</source>
        <translation>Parece que ha iniciado sesión como root, cierre la sesión e inicie sesión como usuario normal para usar este programa.</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="88"/>
        <source>You must run this program with admin access.</source>
        <translation>Debe ejecutar este programa con acceso de administrador.</translation>
    </message>
</context>
</TS>

==> mx-cleanup_25.6.tar.xz: BUILD/translations/mx-cleanup_es_ES.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="es_ES">
<context>
    <name>MainWindow</name>
    <message>
        <location filename="../mainwindow.ui" line="14"/>
        <location filename="../mainwindow.cpp" line="122"/>
        <location filename="../mainwindow.cpp" line="579"/>
        <source>MX Cleanup</source>
        <translation>MX Limpiador</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="663"/>
        <source>Display help </source>
        <translation>Mostrar la ayuda</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="666"/>
        <source>Help</source>
        <translation>Ayuda</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="672"/>
        <source>Alt+H</source>
        <translation>Alt+H</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="638"/>
        <source>About this application</source>
        <translation>Acerca de esta aplicación</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="24"/>
        <source>Main</source>
        <translation>Principal</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="519"/>
        <source>Tools</source>
        <translation>Herramientas</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="525"/>
        <source>Removal Tools</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="563"/>
        <source>Remove MX manuals for languages other than system default</source>
        <translation>Eliminar los manuales MX para idiomas distintos del predeterminado del sistema</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="641"/>
        <source>About...</source>
        <translation>Acerca de...</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="647"/>
        <source>Alt+B</source>
        <translation>Alt+B</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="761"/>
        <source>Quit application</source>
        <translation>Salir de la aplicación</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="764"/>
        <location filename="../mainwindow.cpp" line="680"/>
        <source>Close</source>
        <translation>Cerrar</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="770"/>
        <source>Alt+N</source>
        <translation>Alt+N</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="736"/>
        <source>Apply</source>
        <translation>Aplicar</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="422"/>
        <source>Empty Trash</source>
        <translation>Vaciar papelera</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="431"/>
        <source>Trash older than:</source>
        <translation>Papelera anterior a:</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="176"/>
        <location filename="../mainwindow.ui" line="236"/>
        <location filename="../mainwindow.ui" line="489"/>
        <location filename="../mainwindow.cpp" line="417"/>
        <source> days</source>
        <translation> días</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="444"/>
        <source>All users</source>
        <translation>Todos los usuarios</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="476"/>
        <source>Selected user</source>
        <translation>Usuario seleccionado</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="369"/>
        <source>Clear APT Cache</source>
        <translation>Limpiar Cache de APT</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="384"/>
        <source>Old files</source>
        <translation>Archivos antiguos</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="403"/>
        <source>All files</source>
        <translation>Todos los archivos</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="585"/>
        <source>Graphical Tool for Analyzing Disk Usage</source>
        <translation>Herramienta gráfica para Analizar el Uso del Disco</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="597"/>
        <source>Run Disk Usage Analyzer</source>
        <translation>Ejecutar Analizador de Uso del Disco</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="300"/>
        <source>Schedule</source>
        <translation>Programar</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="312"/>
        <source>No automatic clean</source>
        <translation>Sin limpieza automática</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="319"/>
        <source>At reboot</source>
        <translation>Al reiniciar</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="326"/>
        <source>Daily</source>
        <translation>Diariamente</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="333"/>
        <source>Weekly</source>
        <translation>Semanalmente</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="340"/>
        <source>Monthly</source>
        <translation>Mensualmente</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="58"/>
        <source>Free Disk Space for User</source>
        <translation>Espacio Libre en Disco para el Usuario</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="70"/>
        <location filename="../mainwindow.ui" line="86"/>
        <source>Select user to repair</source>
        <translation>Seleccione el usuario a reparar</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="73"/>
        <source>Select user:</source>
        <translation>Seleccionar usuario:</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="205"/>
        <source>Delete Logs</source>
        <translation>Borrar Registros</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="220"/>
        <source>All logs</source>
        <translation>Todos los registros</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="281"/>
        <source>Old logs</source>
        <translation>Registros antiguos</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="268"/>
        <source>Logs older than:</source>
        <translation>Registros anteriores a:</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="531"/>
        <source>Remove unused WiFi drivers</source>
        <translation>Eliminar controladores de WiFi no utilizados</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="550"/>
        <source>List and select kernels to remove</source>
        <translation>Lista y selección de los kerneles a eliminar</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="36"/>
        <source>Clean Flatpak</source>
        <translation>Limpiar Flatpak</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="42"/>
        <source>Remove unused runtimes</source>
        <translation>Eliminar los tiempos de ejecución no usados</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="102"/>
        <source>Clean Folders</source>
        <translation>Limpiar Carpetas</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="166"/>
        <source>Not accessed for:</source>
        <translation>No accesible por</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="114"/>
        <source>Cache</source>
        <translation>Cache</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="189"/>
        <source>All (potentially dangerous)</source>
        <translation>Todos (potencialmente peligroso)</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="143"/>
        <source>Thumbnails</source>
        <translation>Imágenes en miniatura</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="73"/>
        <source>Remove Manuals</source>
        <translation>Eliminar manuales</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="73"/>
        <source>No manuals to remove.</source>
        <translation>No hay manuales que eliminar.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="80"/>
        <source>Removing packages, please wait</source>
        <translation>Eliminando paquetes, por favor espere</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="254"/>
        <location filename="../mainwindow.cpp" line="720"/>
        <source>Press any key to close</source>
        <translation>Pulse cualquier tecla para cerrar</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="417"/>
        <source> day</source>
        <translation>día</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="432"/>
        <source>Error</source>
        <translation>Error</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="432"/>
        <source>Failed to elevate privileges</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="569"/>
        <source>Done</source>
        <translation>Hecho</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="571"/>
        <source>Cleanup script will run at reboot</source>
        <translation>El script de limpieza se ejecutará al reiniciar</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="572"/>
        <source>Cleanup command done</source>
        <translation>Orden de limpieza hecha</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="572"/>
        <source>%1 MiB were freed</source>
        <translation>%1 MiB fueron liberados</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="579"/>
        <source>About</source>
        <translation>Acerca de</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="580"/>
        <source>Version: </source>
        <translation>Versión: </translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="582"/>
        <source>Quick and safe removal of old files</source>
        <translation>Eliminación rápida y segura de archivos antiguos</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="584"/>
        <source>Copyright (c) MX Linux</source>
        <translation>Copyright (c) MX Linux</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="585"/>
        <source>%1 License</source>
        <translation>%1 Licencia</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="592"/>
        <source>%1 Help</source>
        <translation>%1 Ayuda</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="675"/>
        <source>Kernel currently in use: &lt;b&gt;%1&lt;/b&gt;</source>
        <translation>Kernel actualmente en uso: &lt;b&gt;%1&lt;/b&gt;</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="678"/>
        <source>Remove selected</source>
        <translation>Eliminar lo seleccionado</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="683"/>
        <source>Similar kernels that can be removed:</source>
        <translation>Kerneles similares que pueden eliminarse:</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="684"/>
        <source>Other kernels that can be removed:</source>
        <translation>Otros kerneles que pueden eliminarse:</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="687"/>
        <source>&lt;b&gt;Nothing to remove.&lt;/b&gt; Cannot remove kernel in use.</source>
        <translation>&lt;b&gt;Nada que eliminar.&lt;/b&gt; No puede eliminarse el kernel en uso.</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../about.cpp" line="70"/>
        <source>License</source>
        <translation>Licencia</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="71"/>
        <location filename="../about.cpp" line="81"/>
        <source>Changelog</source>
        <translation>Registro de cambios</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="72"/>
        <source>Cancel</source>
        <translation>Cancelar</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="94"/>
        <source>&amp;Close</source>
        <translation>&amp;Cerrar</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="53"/>
        <source>Quick safe removal of old files</source>
        <translation>Eliminación rápida y segura de archivos antiguos</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="79"/>
        <location filename="../main.cpp" line="87"/>
        <source>Error</source>
        <translation>Error</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="80"/>
        <source>You seem to be logged in as root, please log out and log in as normal user to use this program.</source>
        <translation>Parece que ha iniciado sesión como root, cierre la sesión e inicie sesión como usuario normal para usar este programa.</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="88"/>
        <source>You must run this program with admin access.</source>
        <translation>Debe ejecutar este programa con acceso de administrador.</translation>
    </message>
</context>
</TS>
